@@ -500,6 +500,9 @@ MainWindow::initQML ()
                                           const QString &)),
         this, SLOT   (onSigMosquittoChanges(bool, const QString &, int,
                                             const QString &)));
+    QObject::connect (
+        gObj, SIGNAL(sigPinSettingChanges  (bool, const QString &)),
+        this, SLOT  (onSigPinSettingChanges(bool, const QString &)));
     QObject::connect (gObj, SIGNAL (sigMsgBoxDone(bool)),
                       this, SLOT (onSigMsgBoxDone(bool)));
 
@@ -648,6 +651,10 @@ MainWindow::loginCompleted (bool bOk, const QVariantList &varList)
         if (dbMain.getMqSettings (bMqEnabled, strMqHost, mqPort, strMqTopic)) {
             onSigMosquittoChanges (bMqEnabled, strMqHost, mqPort, strMqTopic);
         }
+
+        if (dbMain.getGvPin (bMqEnabled, strMqHost)) {
+            onSigPinSettingChanges (bMqEnabled, strMqHost);
+        }
     }
 }//MainWindow::loginCompleted
 
@@ -931,7 +938,7 @@ MainWindow::dialNow (const QString &strTarget)
             {
                 setStatus ("Dialing failed instantly");
                 bCallInProgress = bDialCancelled = false;
-                ctx->deleteLater ();
+                fallbackDialout (ctx);
                 break;
             }
         }
@@ -944,7 +951,7 @@ MainWindow::dialNow (const QString &strTarget)
             {
                 setStatus ("Dialing failed instantly");
                 bCallInProgress = bDialCancelled = false;
-                ctx->deleteLater ();
+                fallbackDialout (ctx);
                 break;
             }
         }
@@ -1067,20 +1074,22 @@ MainWindow::dialComplete (bool bOk, const QVariantList &params)
 {
     QMutexLocker locker (&mtxDial);
     DialContext *ctx = (DialContext *) params[1].value <void*> ();
-    if (!bOk)
-    {
-        if (bDialCancelled)
-        {
+    bool bReleaseContext = true;
+
+    if (!bOk) {
+        if (bDialCancelled) {
             setStatus ("Cancelled dial out");
-        }
-        else
-        {
+        } else if (NULL == ctx->fallbackCi) {
+            // Not currently in fallback modem and there was a problem
+            // ... so start fallback mode
+            qDebug ("Attempting fallback dial");
+            bReleaseContext = false;
+            fallbackDialout (ctx);
+        } else {
             setStatus ("Dialing failed", 10*1000);
             this->showMsgBox ("Dialing failed");
         }
-    }
-    else
-    {
+    } else {
         setStatus (QString("Dial successful to %1.").arg(params[0].toString()));
     }
     bCallInProgress = false;
@@ -1088,7 +1097,9 @@ MainWindow::dialComplete (bool bOk, const QVariantList &params)
     OsDependent &osd = Singletons::getRef().getOSD ();
     osd.setLongWork (this, false);
 
-    ctx->deleteLater ();
+    if (bReleaseContext) {
+        ctx->deleteLater ();
+    }
 }//MainWindow::dialComplete
 
 void
@@ -1501,6 +1512,37 @@ MainWindow::onSigMosquittoChanges (bool bEnable, const QString &host, int port,
 #endif
 }//MainWindow::onSigMosquittoChanges
 
+void
+MainWindow::onSigPinSettingChanges(bool bEnable, const QString &pin)
+{
+    CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
+    dbMain.setGvPin (bEnable, pin);
+    if (bEnable) {
+        strGvPin = pin;
+    } else {
+        strGvPin.clear ();
+    }
+
+    do // Begin cleanup block (not a loop)
+    {
+        QObject *pRoot = this->rootObject ();
+        if (NULL == pRoot) {
+            qWarning ("Couldn't get root object in QML for MosquittoPage");
+            break;
+        }
+
+        QObject *pPinSettings = pRoot->findChild <QObject*> ("PinSettingsPage");
+        if (NULL == pPinSettings) {
+            qWarning ("Could not get to PinSettingsPage");
+            break;
+        }
+
+        QMetaObject::invokeMethod (pPinSettings, "setValues",
+                                   Q_ARG (QVariant, QVariant(bEnable)),
+                                   Q_ARG (QVariant, QVariant(pin)));
+    } while (0); // End cleanup block (not a loop)
+}//MainWindow::onSigPinSettingChanges
+
 void
 MainWindow::onMqThreadFinished ()
 {
@@ -1615,3 +1657,49 @@ MainWindow::setPassword(const QString &strP)
                                    Q_ARG (QVariant, QVariant(strP)));
     } while (0); // End cleanup block (not a loop)
 }//MainWindow::setPassword
+
+void
+MainWindow::fallbackDialout (DialContext *ctx)
+{
+    CallInitiatorFactory& cif = Singletons::getRef().getCIFactory ();
+    CalloutInitiatorList listCi = cif.getFallbacks ();
+    if (listCi.length () < 1) {
+        ctx->deleteLater ();
+        this->showMsgBox ("Dialing failed");
+        setStatus ("No fallback dial methods", 10*1000);
+        return;
+    }
+
+    ctx->fallbackCi = listCi[0];
+    QObject::connect (ctx->fallbackCi, SIGNAL(callInitiated(bool,void*)),
+                      this,            SLOT  (onFallbackDialout(bool,void*)));
+    ctx->fallbackCi->initiateCall (ctx->strMyNumber, ctx);
+}//MainWindow::fallbackDialout
+
+void
+MainWindow::onFallbackDialout (bool bSuccess, void *v_ctx)
+{
+    DialContext *ctx = (DialContext *) v_ctx;
+    QObject::disconnect (
+        ctx->fallbackCi, SIGNAL(callInitiated(bool,void*)),
+        this,            SLOT  (onFallbackDialout(bool,void*)));
+
+    if (!bSuccess) {
+        this->showMsgBox ("Dialing failed");
+        qWarning ("Fallback dial failed. Aborting DTMF");
+        setStatus ("Fallback dial failed", 10*1000);
+        return;
+    }
+
+    QString strDTMF;
+    strDTMF = "2p" + ctx->strTarget;
+    // Add the pin if it is there
+    if (!strGvPin.isEmpty ()) {
+        strDTMF = strGvPin + "p" + strDTMF;
+    }
+    strDTMF = "p" + strDTMF + "#";
+
+    ctx->fallbackCi->sendDTMF (strDTMF);
+
+    ctx->deleteLater ();
+}//MainWindow::onFallbackDialout
