@@ -19,7 +19,8 @@ public:
     bool isValid ();
 
 public slots:
-    void initiateCall (const QString &strDestination);
+    void initiateCall (const QString &strDestination, void *ctx = NULL);
+    bool sendDTMF(const QString &strTones);
 
 signals:
     void callDialed();
